Struct AdaptiveFeeVariables
pub struct AdaptiveFeeVariables {
pub last_reference_update_timestamp: u64,
pub last_major_swap_timestamp: u64,
pub volatility_reference: u32,
pub tick_group_index_reference: i32,
pub volatility_accumulator: u32,
pub reserved: [u8; 16],
}Fields
last_reference_update_timestamp: u64last_major_swap_timestamp: u64volatility_reference: u32tick_group_index_reference: i32volatility_accumulator: u32reserved: [u8; 16]Trait Implementations
impl BorshDeserialize for AdaptiveFeeVariables
impl BorshDeserialize for AdaptiveFeeVariables
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<AdaptiveFeeVariables, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for AdaptiveFeeVariables
impl BorshSerialize for AdaptiveFeeVariables
impl Clone for AdaptiveFeeVariables
impl Clone for AdaptiveFeeVariables
fn clone(&self) -> AdaptiveFeeVariables
fn clone(&self) -> AdaptiveFeeVariables
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for AdaptiveFeeVariables
impl Debug for AdaptiveFeeVariables
impl From<AdaptiveFeeVariables> for AdaptiveFeeVariablesFacade
impl From<AdaptiveFeeVariables> for AdaptiveFeeVariablesFacade
fn from(val: AdaptiveFeeVariables) -> AdaptiveFeeVariablesFacade
fn from(val: AdaptiveFeeVariables) -> AdaptiveFeeVariablesFacade
Converts to this type from the input type.
impl PartialEq for AdaptiveFeeVariables
impl PartialEq for AdaptiveFeeVariables
impl Eq for AdaptiveFeeVariables
impl StructuralPartialEq for AdaptiveFeeVariables