Struct CollectProtocolFeesV2InstructionArgs
pub struct CollectProtocolFeesV2InstructionArgs {
pub remaining_accounts_info: Option<RemainingAccountsInfo>,
}Fields
remaining_accounts_info: Option<RemainingAccountsInfo>Trait Implementations
impl BorshDeserialize for CollectProtocolFeesV2InstructionArgs
impl BorshDeserialize for CollectProtocolFeesV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<CollectProtocolFeesV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for CollectProtocolFeesV2InstructionArgs
impl BorshSerialize for CollectProtocolFeesV2InstructionArgs
impl Clone for CollectProtocolFeesV2InstructionArgs
impl Clone for CollectProtocolFeesV2InstructionArgs
fn clone(&self) -> CollectProtocolFeesV2InstructionArgs
fn clone(&self) -> CollectProtocolFeesV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for CollectProtocolFeesV2InstructionArgs
impl PartialEq for CollectProtocolFeesV2InstructionArgs
fn eq(&self, other: &CollectProtocolFeesV2InstructionArgs) -> bool
fn eq(&self, other: &CollectProtocolFeesV2InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CollectProtocolFeesV2InstructionArgs
impl StructuralPartialEq for CollectProtocolFeesV2InstructionArgs