Struct CollectRewardV2InstructionArgs
pub struct CollectRewardV2InstructionArgs {
pub reward_index: u8,
pub remaining_accounts_info: Option<RemainingAccountsInfo>,
}Fields
reward_index: u8remaining_accounts_info: Option<RemainingAccountsInfo>Trait Implementations
impl BorshDeserialize for CollectRewardV2InstructionArgs
impl BorshDeserialize for CollectRewardV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<CollectRewardV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for CollectRewardV2InstructionArgs
impl BorshSerialize for CollectRewardV2InstructionArgs
impl Clone for CollectRewardV2InstructionArgs
impl Clone for CollectRewardV2InstructionArgs
fn clone(&self) -> CollectRewardV2InstructionArgs
fn clone(&self) -> CollectRewardV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for CollectRewardV2InstructionArgs
impl Debug for CollectRewardV2InstructionArgs
impl PartialEq for CollectRewardV2InstructionArgs
impl PartialEq for CollectRewardV2InstructionArgs
impl Eq for CollectRewardV2InstructionArgs
impl StructuralPartialEq for CollectRewardV2InstructionArgs