Struct DecreaseLiquidityV2InstructionArgs
pub struct DecreaseLiquidityV2InstructionArgs {
pub liquidity_amount: u128,
pub token_min_a: u64,
pub token_min_b: u64,
pub remaining_accounts_info: Option<RemainingAccountsInfo>,
}Fields
liquidity_amount: u128token_min_a: u64token_min_b: u64remaining_accounts_info: Option<RemainingAccountsInfo>Trait Implementations
impl BorshDeserialize for DecreaseLiquidityV2InstructionArgs
impl BorshDeserialize for DecreaseLiquidityV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<DecreaseLiquidityV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for DecreaseLiquidityV2InstructionArgs
impl BorshSerialize for DecreaseLiquidityV2InstructionArgs
impl Clone for DecreaseLiquidityV2InstructionArgs
impl Clone for DecreaseLiquidityV2InstructionArgs
fn clone(&self) -> DecreaseLiquidityV2InstructionArgs
fn clone(&self) -> DecreaseLiquidityV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for DecreaseLiquidityV2InstructionArgs
impl Debug for DecreaseLiquidityV2InstructionArgs
impl PartialEq for DecreaseLiquidityV2InstructionArgs
impl PartialEq for DecreaseLiquidityV2InstructionArgs
fn eq(&self, other: &DecreaseLiquidityV2InstructionArgs) -> bool
fn eq(&self, other: &DecreaseLiquidityV2InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for DecreaseLiquidityV2InstructionArgs
impl StructuralPartialEq for DecreaseLiquidityV2InstructionArgs