Struct DynamicTickData
pub struct DynamicTickData {
pub liquidity_net: i128,
pub liquidity_gross: u128,
pub fee_growth_outside_a: u128,
pub fee_growth_outside_b: u128,
pub reward_growths_outside: [u128; 3],
}Fields
liquidity_net: i128liquidity_gross: u128fee_growth_outside_a: u128fee_growth_outside_b: u128reward_growths_outside: [u128; 3]Trait Implementations
impl BorshDeserialize for DynamicTickData
impl BorshDeserialize for DynamicTickData
fn deserialize_reader<__R>(reader: &mut __R) -> Result<DynamicTickData, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for DynamicTickData
impl BorshSerialize for DynamicTickData
impl Clone for DynamicTickData
impl Clone for DynamicTickData
fn clone(&self) -> DynamicTickData
fn clone(&self) -> DynamicTickData
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for DynamicTickData
impl Debug for DynamicTickData
impl PartialEq for DynamicTickData
impl PartialEq for DynamicTickData
impl Eq for DynamicTickData
impl StructuralPartialEq for DynamicTickData