Struct IncreaseLiquidityByTokenAmountsV2InstructionArgs
pub struct IncreaseLiquidityByTokenAmountsV2InstructionArgs {
pub method: IncreaseLiquidityMethod,
pub remaining_accounts_info: Option<RemainingAccountsInfo>,
}Fields
method: IncreaseLiquidityMethodremaining_accounts_info: Option<RemainingAccountsInfo>Trait Implementations
impl BorshDeserialize for IncreaseLiquidityByTokenAmountsV2InstructionArgs
impl BorshDeserialize for IncreaseLiquidityByTokenAmountsV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<IncreaseLiquidityByTokenAmountsV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for IncreaseLiquidityByTokenAmountsV2InstructionArgs
impl BorshSerialize for IncreaseLiquidityByTokenAmountsV2InstructionArgs
impl Clone for IncreaseLiquidityByTokenAmountsV2InstructionArgs
impl Clone for IncreaseLiquidityByTokenAmountsV2InstructionArgs
fn clone(&self) -> IncreaseLiquidityByTokenAmountsV2InstructionArgs
fn clone(&self) -> IncreaseLiquidityByTokenAmountsV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for IncreaseLiquidityByTokenAmountsV2InstructionArgs
impl PartialEq for IncreaseLiquidityByTokenAmountsV2InstructionArgs
fn eq(&self, other: &IncreaseLiquidityByTokenAmountsV2InstructionArgs) -> bool
fn eq(&self, other: &IncreaseLiquidityByTokenAmountsV2InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for IncreaseLiquidityByTokenAmountsV2InstructionArgs
impl StructuralPartialEq for IncreaseLiquidityByTokenAmountsV2InstructionArgs