Struct IncreaseLiquidityV2InstructionArgs
pub struct IncreaseLiquidityV2InstructionArgs {
pub liquidity_amount: u128,
pub token_max_a: u64,
pub token_max_b: u64,
pub remaining_accounts_info: Option<RemainingAccountsInfo>,
}Fields
liquidity_amount: u128token_max_a: u64token_max_b: u64remaining_accounts_info: Option<RemainingAccountsInfo>Trait Implementations
impl BorshDeserialize for IncreaseLiquidityV2InstructionArgs
impl BorshDeserialize for IncreaseLiquidityV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<IncreaseLiquidityV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for IncreaseLiquidityV2InstructionArgs
impl BorshSerialize for IncreaseLiquidityV2InstructionArgs
impl Clone for IncreaseLiquidityV2InstructionArgs
impl Clone for IncreaseLiquidityV2InstructionArgs
fn clone(&self) -> IncreaseLiquidityV2InstructionArgs
fn clone(&self) -> IncreaseLiquidityV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for IncreaseLiquidityV2InstructionArgs
impl Debug for IncreaseLiquidityV2InstructionArgs
impl PartialEq for IncreaseLiquidityV2InstructionArgs
impl PartialEq for IncreaseLiquidityV2InstructionArgs
fn eq(&self, other: &IncreaseLiquidityV2InstructionArgs) -> bool
fn eq(&self, other: &IncreaseLiquidityV2InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for IncreaseLiquidityV2InstructionArgs
impl StructuralPartialEq for IncreaseLiquidityV2InstructionArgs