Struct InitializeAdaptiveFeeTierInstructionArgs
pub struct InitializeAdaptiveFeeTierInstructionArgs {
pub fee_tier_index: u16,
pub tick_spacing: u16,
pub initialize_pool_authority: Address,
pub delegated_fee_authority: Address,
pub default_base_fee_rate: u16,
pub filter_period: u16,
pub decay_period: u16,
pub reduction_factor: u16,
pub adaptive_fee_control_factor: u32,
pub max_volatility_accumulator: u32,
pub tick_group_size: u16,
pub major_swap_threshold_ticks: u16,
}Fields
fee_tier_index: u16tick_spacing: u16default_base_fee_rate: u16filter_period: u16decay_period: u16reduction_factor: u16adaptive_fee_control_factor: u32max_volatility_accumulator: u32tick_group_size: u16major_swap_threshold_ticks: u16Trait Implementations
impl BorshDeserialize for InitializeAdaptiveFeeTierInstructionArgs
impl BorshDeserialize for InitializeAdaptiveFeeTierInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<InitializeAdaptiveFeeTierInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for InitializeAdaptiveFeeTierInstructionArgs
impl BorshSerialize for InitializeAdaptiveFeeTierInstructionArgs
impl Clone for InitializeAdaptiveFeeTierInstructionArgs
impl Clone for InitializeAdaptiveFeeTierInstructionArgs
fn clone(&self) -> InitializeAdaptiveFeeTierInstructionArgs
fn clone(&self) -> InitializeAdaptiveFeeTierInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for InitializeAdaptiveFeeTierInstructionArgs
impl PartialEq for InitializeAdaptiveFeeTierInstructionArgs
fn eq(&self, other: &InitializeAdaptiveFeeTierInstructionArgs) -> bool
fn eq(&self, other: &InitializeAdaptiveFeeTierInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InitializeAdaptiveFeeTierInstructionArgs
impl StructuralPartialEq for InitializeAdaptiveFeeTierInstructionArgs