Struct InitializeConfigInstructionArgs
pub struct InitializeConfigInstructionArgs {
pub fee_authority: Address,
pub collect_protocol_fees_authority: Address,
pub reward_emissions_super_authority: Address,
pub default_protocol_fee_rate: u16,
}Fields
default_protocol_fee_rate: u16Trait Implementations
impl BorshDeserialize for InitializeConfigInstructionArgs
impl BorshDeserialize for InitializeConfigInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<InitializeConfigInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for InitializeConfigInstructionArgs
impl BorshSerialize for InitializeConfigInstructionArgs
impl Clone for InitializeConfigInstructionArgs
impl Clone for InitializeConfigInstructionArgs
fn clone(&self) -> InitializeConfigInstructionArgs
fn clone(&self) -> InitializeConfigInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for InitializeConfigInstructionArgs
impl Debug for InitializeConfigInstructionArgs
impl Eq for InitializeConfigInstructionArgs
impl StructuralPartialEq for InitializeConfigInstructionArgs