Struct InitializeDynamicTickArrayInstructionArgs
pub struct InitializeDynamicTickArrayInstructionArgs {
pub start_tick_index: i32,
pub idempotent: bool,
}Fields
start_tick_index: i32idempotent: boolTrait Implementations
impl BorshDeserialize for InitializeDynamicTickArrayInstructionArgs
impl BorshDeserialize for InitializeDynamicTickArrayInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<InitializeDynamicTickArrayInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for InitializeDynamicTickArrayInstructionArgs
impl BorshSerialize for InitializeDynamicTickArrayInstructionArgs
impl Clone for InitializeDynamicTickArrayInstructionArgs
impl Clone for InitializeDynamicTickArrayInstructionArgs
fn clone(&self) -> InitializeDynamicTickArrayInstructionArgs
fn clone(&self) -> InitializeDynamicTickArrayInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for InitializeDynamicTickArrayInstructionArgs
impl PartialEq for InitializeDynamicTickArrayInstructionArgs
fn eq(&self, other: &InitializeDynamicTickArrayInstructionArgs) -> bool
fn eq(&self, other: &InitializeDynamicTickArrayInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InitializeDynamicTickArrayInstructionArgs
impl StructuralPartialEq for InitializeDynamicTickArrayInstructionArgs