Struct InitializeFeeTierInstructionArgs
pub struct InitializeFeeTierInstructionArgs {
pub tick_spacing: u16,
pub default_fee_rate: u16,
}Fields
tick_spacing: u16default_fee_rate: u16Trait Implementations
impl BorshDeserialize for InitializeFeeTierInstructionArgs
impl BorshDeserialize for InitializeFeeTierInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<InitializeFeeTierInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for InitializeFeeTierInstructionArgs
impl BorshSerialize for InitializeFeeTierInstructionArgs
impl Clone for InitializeFeeTierInstructionArgs
impl Clone for InitializeFeeTierInstructionArgs
fn clone(&self) -> InitializeFeeTierInstructionArgs
fn clone(&self) -> InitializeFeeTierInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for InitializeFeeTierInstructionArgs
impl Debug for InitializeFeeTierInstructionArgs
impl Eq for InitializeFeeTierInstructionArgs
impl StructuralPartialEq for InitializeFeeTierInstructionArgs