Struct InitializePoolV2InstructionArgs
pub struct InitializePoolV2InstructionArgs {
pub tick_spacing: u16,
pub initial_sqrt_price: u128,
}Fields
tick_spacing: u16initial_sqrt_price: u128Trait Implementations
impl BorshDeserialize for InitializePoolV2InstructionArgs
impl BorshDeserialize for InitializePoolV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<InitializePoolV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for InitializePoolV2InstructionArgs
impl BorshSerialize for InitializePoolV2InstructionArgs
impl Clone for InitializePoolV2InstructionArgs
impl Clone for InitializePoolV2InstructionArgs
fn clone(&self) -> InitializePoolV2InstructionArgs
fn clone(&self) -> InitializePoolV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for InitializePoolV2InstructionArgs
impl Debug for InitializePoolV2InstructionArgs
impl Eq for InitializePoolV2InstructionArgs
impl StructuralPartialEq for InitializePoolV2InstructionArgs