Struct InitializePoolWithAdaptiveFeeInstructionArgs
pub struct InitializePoolWithAdaptiveFeeInstructionArgs {
pub initial_sqrt_price: u128,
pub trade_enable_timestamp: Option<u64>,
}Fields
initial_sqrt_price: u128trade_enable_timestamp: Option<u64>Trait Implementations
impl BorshDeserialize for InitializePoolWithAdaptiveFeeInstructionArgs
impl BorshDeserialize for InitializePoolWithAdaptiveFeeInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<InitializePoolWithAdaptiveFeeInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for InitializePoolWithAdaptiveFeeInstructionArgs
impl BorshSerialize for InitializePoolWithAdaptiveFeeInstructionArgs
impl Clone for InitializePoolWithAdaptiveFeeInstructionArgs
impl Clone for InitializePoolWithAdaptiveFeeInstructionArgs
fn clone(&self) -> InitializePoolWithAdaptiveFeeInstructionArgs
fn clone(&self) -> InitializePoolWithAdaptiveFeeInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for InitializePoolWithAdaptiveFeeInstructionArgs
impl PartialEq for InitializePoolWithAdaptiveFeeInstructionArgs
fn eq(&self, other: &InitializePoolWithAdaptiveFeeInstructionArgs) -> bool
fn eq(&self, other: &InitializePoolWithAdaptiveFeeInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InitializePoolWithAdaptiveFeeInstructionArgs
impl StructuralPartialEq for InitializePoolWithAdaptiveFeeInstructionArgs