Struct InitializeRewardInstructionArgs
pub struct InitializeRewardInstructionArgs {
pub reward_index: u8,
}Fields
reward_index: u8Trait Implementations
impl BorshDeserialize for InitializeRewardInstructionArgs
impl BorshDeserialize for InitializeRewardInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<InitializeRewardInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for InitializeRewardInstructionArgs
impl BorshSerialize for InitializeRewardInstructionArgs
impl Clone for InitializeRewardInstructionArgs
impl Clone for InitializeRewardInstructionArgs
fn clone(&self) -> InitializeRewardInstructionArgs
fn clone(&self) -> InitializeRewardInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for InitializeRewardInstructionArgs
impl Debug for InitializeRewardInstructionArgs
impl Eq for InitializeRewardInstructionArgs
impl StructuralPartialEq for InitializeRewardInstructionArgs