Struct InitializeRewardV2InstructionArgs
pub struct InitializeRewardV2InstructionArgs {
pub reward_index: u8,
}Fields
reward_index: u8Trait Implementations
impl BorshDeserialize for InitializeRewardV2InstructionArgs
impl BorshDeserialize for InitializeRewardV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<InitializeRewardV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for InitializeRewardV2InstructionArgs
impl BorshSerialize for InitializeRewardV2InstructionArgs
impl Clone for InitializeRewardV2InstructionArgs
impl Clone for InitializeRewardV2InstructionArgs
fn clone(&self) -> InitializeRewardV2InstructionArgs
fn clone(&self) -> InitializeRewardV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for InitializeRewardV2InstructionArgs
impl Debug for InitializeRewardV2InstructionArgs
impl Eq for InitializeRewardV2InstructionArgs
impl StructuralPartialEq for InitializeRewardV2InstructionArgs