Struct InitializeTickArrayInstructionArgs
pub struct InitializeTickArrayInstructionArgs {
pub start_tick_index: i32,
}Fields
start_tick_index: i32Trait Implementations
impl BorshDeserialize for InitializeTickArrayInstructionArgs
impl BorshDeserialize for InitializeTickArrayInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<InitializeTickArrayInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for InitializeTickArrayInstructionArgs
impl BorshSerialize for InitializeTickArrayInstructionArgs
impl Clone for InitializeTickArrayInstructionArgs
impl Clone for InitializeTickArrayInstructionArgs
fn clone(&self) -> InitializeTickArrayInstructionArgs
fn clone(&self) -> InitializeTickArrayInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for InitializeTickArrayInstructionArgs
impl Debug for InitializeTickArrayInstructionArgs
impl PartialEq for InitializeTickArrayInstructionArgs
impl PartialEq for InitializeTickArrayInstructionArgs
fn eq(&self, other: &InitializeTickArrayInstructionArgs) -> bool
fn eq(&self, other: &InitializeTickArrayInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InitializeTickArrayInstructionArgs
impl StructuralPartialEq for InitializeTickArrayInstructionArgs