Struct LiquidityDecreased
pub struct LiquidityDecreased {
pub whirlpool: Address,
pub position: Address,
pub tick_lower_index: i32,
pub tick_upper_index: i32,
pub liquidity: u128,
pub token_a_amount: u64,
pub token_b_amount: u64,
pub token_a_transfer_fee: u64,
pub token_b_transfer_fee: u64,
}Fields
whirlpool: Addressposition: Addresstick_lower_index: i32tick_upper_index: i32liquidity: u128token_a_amount: u64token_b_amount: u64token_a_transfer_fee: u64token_b_transfer_fee: u64Trait Implementations
impl BorshDeserialize for LiquidityDecreased
impl BorshDeserialize for LiquidityDecreased
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<LiquidityDecreased, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for LiquidityDecreased
impl BorshSerialize for LiquidityDecreased
impl Clone for LiquidityDecreased
impl Clone for LiquidityDecreased
fn clone(&self) -> LiquidityDecreased
fn clone(&self) -> LiquidityDecreased
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for LiquidityDecreased
impl Debug for LiquidityDecreased
impl PartialEq for LiquidityDecreased
impl PartialEq for LiquidityDecreased
impl Eq for LiquidityDecreased
impl StructuralPartialEq for LiquidityDecreased