Struct LiquidityRepositioned
pub struct LiquidityRepositioned {Show 18 fields
pub whirlpool: Address,
pub position: Address,
pub existing_range_tick_lower_index: i32,
pub existing_range_tick_upper_index: i32,
pub new_range_tick_lower_index: i32,
pub new_range_tick_upper_index: i32,
pub existing_range_liquidity: u128,
pub new_range_liquidity: u128,
pub existing_range_token_a_amount: u64,
pub existing_range_token_b_amount: u64,
pub new_range_token_a_amount: u64,
pub new_range_token_b_amount: u64,
pub token_a_transfer_amount: u64,
pub token_a_transfer_fee: u64,
pub is_token_a_transfer_from_owner: bool,
pub token_b_transfer_amount: u64,
pub token_b_transfer_fee: u64,
pub is_token_b_transfer_from_owner: bool,
}Fields
whirlpool: Addressposition: Addressexisting_range_tick_lower_index: i32existing_range_tick_upper_index: i32new_range_tick_lower_index: i32new_range_tick_upper_index: i32existing_range_liquidity: u128new_range_liquidity: u128existing_range_token_a_amount: u64existing_range_token_b_amount: u64new_range_token_a_amount: u64new_range_token_b_amount: u64token_a_transfer_amount: u64token_a_transfer_fee: u64is_token_a_transfer_from_owner: booltoken_b_transfer_amount: u64token_b_transfer_fee: u64is_token_b_transfer_from_owner: boolTrait Implementations
impl BorshDeserialize for LiquidityRepositioned
impl BorshDeserialize for LiquidityRepositioned
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<LiquidityRepositioned, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for LiquidityRepositioned
impl BorshSerialize for LiquidityRepositioned
impl Clone for LiquidityRepositioned
impl Clone for LiquidityRepositioned
fn clone(&self) -> LiquidityRepositioned
fn clone(&self) -> LiquidityRepositioned
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for LiquidityRepositioned
impl Debug for LiquidityRepositioned
impl PartialEq for LiquidityRepositioned
impl PartialEq for LiquidityRepositioned
impl Eq for LiquidityRepositioned
impl StructuralPartialEq for LiquidityRepositioned