Struct LockPositionInstructionArgs
pub struct LockPositionInstructionArgs {
pub lock_type: LockType,
}Fields
lock_type: LockTypeTrait Implementations
impl BorshDeserialize for LockPositionInstructionArgs
impl BorshDeserialize for LockPositionInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<LockPositionInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for LockPositionInstructionArgs
impl BorshSerialize for LockPositionInstructionArgs
impl Clone for LockPositionInstructionArgs
impl Clone for LockPositionInstructionArgs
fn clone(&self) -> LockPositionInstructionArgs
fn clone(&self) -> LockPositionInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for LockPositionInstructionArgs
impl Debug for LockPositionInstructionArgs
impl PartialEq for LockPositionInstructionArgs
impl PartialEq for LockPositionInstructionArgs
impl Eq for LockPositionInstructionArgs
impl StructuralPartialEq for LockPositionInstructionArgs