Struct OpenPositionInstructionArgs
pub struct OpenPositionInstructionArgs {
pub position_bump: u8,
pub tick_lower_index: i32,
pub tick_upper_index: i32,
}Fields
position_bump: u8tick_lower_index: i32tick_upper_index: i32Trait Implementations
impl BorshDeserialize for OpenPositionInstructionArgs
impl BorshDeserialize for OpenPositionInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<OpenPositionInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for OpenPositionInstructionArgs
impl BorshSerialize for OpenPositionInstructionArgs
impl Clone for OpenPositionInstructionArgs
impl Clone for OpenPositionInstructionArgs
fn clone(&self) -> OpenPositionInstructionArgs
fn clone(&self) -> OpenPositionInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for OpenPositionInstructionArgs
impl Debug for OpenPositionInstructionArgs
impl PartialEq for OpenPositionInstructionArgs
impl PartialEq for OpenPositionInstructionArgs
impl Eq for OpenPositionInstructionArgs
impl StructuralPartialEq for OpenPositionInstructionArgs