Struct OpenPositionWithTokenExtensionsInstructionArgs
pub struct OpenPositionWithTokenExtensionsInstructionArgs {
pub tick_lower_index: i32,
pub tick_upper_index: i32,
pub with_token_metadata_extension: bool,
}Fields
tick_lower_index: i32tick_upper_index: i32with_token_metadata_extension: boolTrait Implementations
impl BorshDeserialize for OpenPositionWithTokenExtensionsInstructionArgs
impl BorshDeserialize for OpenPositionWithTokenExtensionsInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<OpenPositionWithTokenExtensionsInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for OpenPositionWithTokenExtensionsInstructionArgs
impl BorshSerialize for OpenPositionWithTokenExtensionsInstructionArgs
impl Clone for OpenPositionWithTokenExtensionsInstructionArgs
impl Clone for OpenPositionWithTokenExtensionsInstructionArgs
fn clone(&self) -> OpenPositionWithTokenExtensionsInstructionArgs
fn clone(&self) -> OpenPositionWithTokenExtensionsInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for OpenPositionWithTokenExtensionsInstructionArgs
impl PartialEq for OpenPositionWithTokenExtensionsInstructionArgs
fn eq(&self, other: &OpenPositionWithTokenExtensionsInstructionArgs) -> bool
fn eq(&self, other: &OpenPositionWithTokenExtensionsInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for OpenPositionWithTokenExtensionsInstructionArgs
impl StructuralPartialEq for OpenPositionWithTokenExtensionsInstructionArgs