Struct PoolInitialized
pub struct PoolInitialized {
pub whirlpool: Address,
pub whirlpools_config: Address,
pub token_mint_a: Address,
pub token_mint_b: Address,
pub tick_spacing: u16,
pub token_program_a: Address,
pub token_program_b: Address,
pub decimals_a: u8,
pub decimals_b: u8,
pub initial_sqrt_price: u128,
}Fields
whirlpool: Addresswhirlpools_config: Addresstoken_mint_a: Addresstoken_mint_b: Addresstick_spacing: u16token_program_a: Addresstoken_program_b: Addressdecimals_a: u8decimals_b: u8initial_sqrt_price: u128Trait Implementations
impl BorshDeserialize for PoolInitialized
impl BorshDeserialize for PoolInitialized
fn deserialize_reader<__R>(reader: &mut __R) -> Result<PoolInitialized, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for PoolInitialized
impl BorshSerialize for PoolInitialized
impl Clone for PoolInitialized
impl Clone for PoolInitialized
fn clone(&self) -> PoolInitialized
fn clone(&self) -> PoolInitialized
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for PoolInitialized
impl Debug for PoolInitialized
impl PartialEq for PoolInitialized
impl PartialEq for PoolInitialized
impl Eq for PoolInitialized
impl StructuralPartialEq for PoolInitialized