Struct PositionOpened
pub struct PositionOpened {
pub whirlpool: Address,
pub position: Address,
pub tick_lower_index: i32,
pub tick_upper_index: i32,
}Fields
whirlpool: Addressposition: Addresstick_lower_index: i32tick_upper_index: i32Trait Implementations
impl BorshDeserialize for PositionOpened
impl BorshDeserialize for PositionOpened
fn deserialize_reader<__R>(reader: &mut __R) -> Result<PositionOpened, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for PositionOpened
impl BorshSerialize for PositionOpened
impl Clone for PositionOpened
impl Clone for PositionOpened
fn clone(&self) -> PositionOpened
fn clone(&self) -> PositionOpened
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for PositionOpened
impl Debug for PositionOpened
impl PartialEq for PositionOpened
impl PartialEq for PositionOpened
impl Eq for PositionOpened
impl StructuralPartialEq for PositionOpened