Struct RemainingAccountsInfo
pub struct RemainingAccountsInfo {
pub slices: Vec<RemainingAccountsSlice>,
}Fields
slices: Vec<RemainingAccountsSlice>Trait Implementations
impl BorshDeserialize for RemainingAccountsInfo
impl BorshDeserialize for RemainingAccountsInfo
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<RemainingAccountsInfo, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for RemainingAccountsInfo
impl BorshSerialize for RemainingAccountsInfo
impl Clone for RemainingAccountsInfo
impl Clone for RemainingAccountsInfo
fn clone(&self) -> RemainingAccountsInfo
fn clone(&self) -> RemainingAccountsInfo
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for RemainingAccountsInfo
impl Debug for RemainingAccountsInfo
impl PartialEq for RemainingAccountsInfo
impl PartialEq for RemainingAccountsInfo
impl Eq for RemainingAccountsInfo
impl StructuralPartialEq for RemainingAccountsInfo