Struct RemainingAccountsSlice
pub struct RemainingAccountsSlice {
pub accounts_type: AccountsType,
pub length: u8,
}Fields
accounts_type: AccountsTypelength: u8Trait Implementations
impl BorshDeserialize for RemainingAccountsSlice
impl BorshDeserialize for RemainingAccountsSlice
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<RemainingAccountsSlice, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for RemainingAccountsSlice
impl BorshSerialize for RemainingAccountsSlice
impl Clone for RemainingAccountsSlice
impl Clone for RemainingAccountsSlice
fn clone(&self) -> RemainingAccountsSlice
fn clone(&self) -> RemainingAccountsSlice
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for RemainingAccountsSlice
impl Debug for RemainingAccountsSlice
impl PartialEq for RemainingAccountsSlice
impl PartialEq for RemainingAccountsSlice
impl Eq for RemainingAccountsSlice
impl StructuralPartialEq for RemainingAccountsSlice