Struct RepositionLiquidityV2InstructionArgs
pub struct RepositionLiquidityV2InstructionArgs {
pub new_tick_lower_index: i32,
pub new_tick_upper_index: i32,
pub method: RepositionLiquidityMethod,
pub remaining_accounts_info: Option<RemainingAccountsInfo>,
}Fields
new_tick_lower_index: i32new_tick_upper_index: i32method: RepositionLiquidityMethodremaining_accounts_info: Option<RemainingAccountsInfo>Trait Implementations
impl BorshDeserialize for RepositionLiquidityV2InstructionArgs
impl BorshDeserialize for RepositionLiquidityV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<RepositionLiquidityV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for RepositionLiquidityV2InstructionArgs
impl BorshSerialize for RepositionLiquidityV2InstructionArgs
impl Clone for RepositionLiquidityV2InstructionArgs
impl Clone for RepositionLiquidityV2InstructionArgs
fn clone(&self) -> RepositionLiquidityV2InstructionArgs
fn clone(&self) -> RepositionLiquidityV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for RepositionLiquidityV2InstructionArgs
impl PartialEq for RepositionLiquidityV2InstructionArgs
fn eq(&self, other: &RepositionLiquidityV2InstructionArgs) -> bool
fn eq(&self, other: &RepositionLiquidityV2InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RepositionLiquidityV2InstructionArgs
impl StructuralPartialEq for RepositionLiquidityV2InstructionArgs