Struct ResetPositionRangeInstructionArgs
pub struct ResetPositionRangeInstructionArgs {
pub new_tick_lower_index: i32,
pub new_tick_upper_index: i32,
}Fields
new_tick_lower_index: i32new_tick_upper_index: i32Trait Implementations
impl BorshDeserialize for ResetPositionRangeInstructionArgs
impl BorshDeserialize for ResetPositionRangeInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<ResetPositionRangeInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for ResetPositionRangeInstructionArgs
impl BorshSerialize for ResetPositionRangeInstructionArgs
impl Clone for ResetPositionRangeInstructionArgs
impl Clone for ResetPositionRangeInstructionArgs
fn clone(&self) -> ResetPositionRangeInstructionArgs
fn clone(&self) -> ResetPositionRangeInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for ResetPositionRangeInstructionArgs
impl Debug for ResetPositionRangeInstructionArgs
impl Eq for ResetPositionRangeInstructionArgs
impl StructuralPartialEq for ResetPositionRangeInstructionArgs