Struct SetAdaptiveFeeConstantsInstructionArgs
pub struct SetAdaptiveFeeConstantsInstructionArgs {
pub filter_period: Option<u16>,
pub decay_period: Option<u16>,
pub reduction_factor: Option<u16>,
pub adaptive_fee_control_factor: Option<u32>,
pub max_volatility_accumulator: Option<u32>,
pub tick_group_size: Option<u16>,
pub major_swap_threshold_ticks: Option<u16>,
}Fields
filter_period: Option<u16>decay_period: Option<u16>reduction_factor: Option<u16>adaptive_fee_control_factor: Option<u32>max_volatility_accumulator: Option<u32>tick_group_size: Option<u16>major_swap_threshold_ticks: Option<u16>Trait Implementations
impl BorshDeserialize for SetAdaptiveFeeConstantsInstructionArgs
impl BorshDeserialize for SetAdaptiveFeeConstantsInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetAdaptiveFeeConstantsInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetAdaptiveFeeConstantsInstructionArgs
impl BorshSerialize for SetAdaptiveFeeConstantsInstructionArgs
impl Clone for SetAdaptiveFeeConstantsInstructionArgs
impl Clone for SetAdaptiveFeeConstantsInstructionArgs
fn clone(&self) -> SetAdaptiveFeeConstantsInstructionArgs
fn clone(&self) -> SetAdaptiveFeeConstantsInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for SetAdaptiveFeeConstantsInstructionArgs
impl PartialEq for SetAdaptiveFeeConstantsInstructionArgs
fn eq(&self, other: &SetAdaptiveFeeConstantsInstructionArgs) -> bool
fn eq(&self, other: &SetAdaptiveFeeConstantsInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetAdaptiveFeeConstantsInstructionArgs
impl StructuralPartialEq for SetAdaptiveFeeConstantsInstructionArgs