Struct SetConfigFeatureFlagInstructionArgs
pub struct SetConfigFeatureFlagInstructionArgs {
pub feature_flag: ConfigFeatureFlag,
}Fields
feature_flag: ConfigFeatureFlagTrait Implementations
impl BorshDeserialize for SetConfigFeatureFlagInstructionArgs
impl BorshDeserialize for SetConfigFeatureFlagInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetConfigFeatureFlagInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetConfigFeatureFlagInstructionArgs
impl BorshSerialize for SetConfigFeatureFlagInstructionArgs
impl Clone for SetConfigFeatureFlagInstructionArgs
impl Clone for SetConfigFeatureFlagInstructionArgs
fn clone(&self) -> SetConfigFeatureFlagInstructionArgs
fn clone(&self) -> SetConfigFeatureFlagInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for SetConfigFeatureFlagInstructionArgs
impl PartialEq for SetConfigFeatureFlagInstructionArgs
fn eq(&self, other: &SetConfigFeatureFlagInstructionArgs) -> bool
fn eq(&self, other: &SetConfigFeatureFlagInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetConfigFeatureFlagInstructionArgs
impl StructuralPartialEq for SetConfigFeatureFlagInstructionArgs