Struct SetDefaultBaseFeeRateInstructionArgs
pub struct SetDefaultBaseFeeRateInstructionArgs {
pub default_base_fee_rate: u16,
}Fields
default_base_fee_rate: u16Trait Implementations
impl BorshDeserialize for SetDefaultBaseFeeRateInstructionArgs
impl BorshDeserialize for SetDefaultBaseFeeRateInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetDefaultBaseFeeRateInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetDefaultBaseFeeRateInstructionArgs
impl BorshSerialize for SetDefaultBaseFeeRateInstructionArgs
impl Clone for SetDefaultBaseFeeRateInstructionArgs
impl Clone for SetDefaultBaseFeeRateInstructionArgs
fn clone(&self) -> SetDefaultBaseFeeRateInstructionArgs
fn clone(&self) -> SetDefaultBaseFeeRateInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for SetDefaultBaseFeeRateInstructionArgs
impl PartialEq for SetDefaultBaseFeeRateInstructionArgs
fn eq(&self, other: &SetDefaultBaseFeeRateInstructionArgs) -> bool
fn eq(&self, other: &SetDefaultBaseFeeRateInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetDefaultBaseFeeRateInstructionArgs
impl StructuralPartialEq for SetDefaultBaseFeeRateInstructionArgs