Struct SetDefaultFeeRateInstructionArgs
pub struct SetDefaultFeeRateInstructionArgs {
pub default_fee_rate: u16,
}Fields
default_fee_rate: u16Trait Implementations
impl BorshDeserialize for SetDefaultFeeRateInstructionArgs
impl BorshDeserialize for SetDefaultFeeRateInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetDefaultFeeRateInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetDefaultFeeRateInstructionArgs
impl BorshSerialize for SetDefaultFeeRateInstructionArgs
impl Clone for SetDefaultFeeRateInstructionArgs
impl Clone for SetDefaultFeeRateInstructionArgs
fn clone(&self) -> SetDefaultFeeRateInstructionArgs
fn clone(&self) -> SetDefaultFeeRateInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for SetDefaultFeeRateInstructionArgs
impl Debug for SetDefaultFeeRateInstructionArgs
impl Eq for SetDefaultFeeRateInstructionArgs
impl StructuralPartialEq for SetDefaultFeeRateInstructionArgs