Struct SetFeeRateByDelegatedFeeAuthorityInstructionArgs
pub struct SetFeeRateByDelegatedFeeAuthorityInstructionArgs {
pub fee_rate: u16,
}Fields
fee_rate: u16Trait Implementations
impl BorshDeserialize for SetFeeRateByDelegatedFeeAuthorityInstructionArgs
impl BorshDeserialize for SetFeeRateByDelegatedFeeAuthorityInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetFeeRateByDelegatedFeeAuthorityInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetFeeRateByDelegatedFeeAuthorityInstructionArgs
impl BorshSerialize for SetFeeRateByDelegatedFeeAuthorityInstructionArgs
impl Clone for SetFeeRateByDelegatedFeeAuthorityInstructionArgs
impl Clone for SetFeeRateByDelegatedFeeAuthorityInstructionArgs
fn clone(&self) -> SetFeeRateByDelegatedFeeAuthorityInstructionArgs
fn clone(&self) -> SetFeeRateByDelegatedFeeAuthorityInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for SetFeeRateByDelegatedFeeAuthorityInstructionArgs
impl PartialEq for SetFeeRateByDelegatedFeeAuthorityInstructionArgs
fn eq(&self, other: &SetFeeRateByDelegatedFeeAuthorityInstructionArgs) -> bool
fn eq(&self, other: &SetFeeRateByDelegatedFeeAuthorityInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetFeeRateByDelegatedFeeAuthorityInstructionArgs
impl StructuralPartialEq for SetFeeRateByDelegatedFeeAuthorityInstructionArgs