Struct SetFeeRateInstructionArgs
pub struct SetFeeRateInstructionArgs {
pub fee_rate: u16,
}Fields
fee_rate: u16Trait Implementations
impl BorshDeserialize for SetFeeRateInstructionArgs
impl BorshDeserialize for SetFeeRateInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetFeeRateInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetFeeRateInstructionArgs
impl BorshSerialize for SetFeeRateInstructionArgs
impl Clone for SetFeeRateInstructionArgs
impl Clone for SetFeeRateInstructionArgs
fn clone(&self) -> SetFeeRateInstructionArgs
fn clone(&self) -> SetFeeRateInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for SetFeeRateInstructionArgs
impl Debug for SetFeeRateInstructionArgs
impl PartialEq for SetFeeRateInstructionArgs
impl PartialEq for SetFeeRateInstructionArgs
impl Eq for SetFeeRateInstructionArgs
impl StructuralPartialEq for SetFeeRateInstructionArgs