Struct SetPresetAdaptiveFeeConstantsInstructionArgs
pub struct SetPresetAdaptiveFeeConstantsInstructionArgs {
pub filter_period: u16,
pub decay_period: u16,
pub reduction_factor: u16,
pub adaptive_fee_control_factor: u32,
pub max_volatility_accumulator: u32,
pub tick_group_size: u16,
pub major_swap_threshold_ticks: u16,
}Fields
filter_period: u16decay_period: u16reduction_factor: u16adaptive_fee_control_factor: u32max_volatility_accumulator: u32tick_group_size: u16major_swap_threshold_ticks: u16Trait Implementations
impl BorshDeserialize for SetPresetAdaptiveFeeConstantsInstructionArgs
impl BorshDeserialize for SetPresetAdaptiveFeeConstantsInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetPresetAdaptiveFeeConstantsInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetPresetAdaptiveFeeConstantsInstructionArgs
impl BorshSerialize for SetPresetAdaptiveFeeConstantsInstructionArgs
impl Clone for SetPresetAdaptiveFeeConstantsInstructionArgs
impl Clone for SetPresetAdaptiveFeeConstantsInstructionArgs
fn clone(&self) -> SetPresetAdaptiveFeeConstantsInstructionArgs
fn clone(&self) -> SetPresetAdaptiveFeeConstantsInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for SetPresetAdaptiveFeeConstantsInstructionArgs
impl PartialEq for SetPresetAdaptiveFeeConstantsInstructionArgs
fn eq(&self, other: &SetPresetAdaptiveFeeConstantsInstructionArgs) -> bool
fn eq(&self, other: &SetPresetAdaptiveFeeConstantsInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetPresetAdaptiveFeeConstantsInstructionArgs
impl StructuralPartialEq for SetPresetAdaptiveFeeConstantsInstructionArgs