Struct SetProtocolFeeRateInstructionArgs
pub struct SetProtocolFeeRateInstructionArgs {
pub protocol_fee_rate: u16,
}Fields
protocol_fee_rate: u16Trait Implementations
impl BorshDeserialize for SetProtocolFeeRateInstructionArgs
impl BorshDeserialize for SetProtocolFeeRateInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetProtocolFeeRateInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetProtocolFeeRateInstructionArgs
impl BorshSerialize for SetProtocolFeeRateInstructionArgs
impl Clone for SetProtocolFeeRateInstructionArgs
impl Clone for SetProtocolFeeRateInstructionArgs
fn clone(&self) -> SetProtocolFeeRateInstructionArgs
fn clone(&self) -> SetProtocolFeeRateInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for SetProtocolFeeRateInstructionArgs
impl Debug for SetProtocolFeeRateInstructionArgs
impl Eq for SetProtocolFeeRateInstructionArgs
impl StructuralPartialEq for SetProtocolFeeRateInstructionArgs