Struct SetRewardAuthorityInstructionArgs
pub struct SetRewardAuthorityInstructionArgs {
pub reward_index: u8,
}Fields
reward_index: u8Trait Implementations
impl BorshDeserialize for SetRewardAuthorityInstructionArgs
impl BorshDeserialize for SetRewardAuthorityInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetRewardAuthorityInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetRewardAuthorityInstructionArgs
impl BorshSerialize for SetRewardAuthorityInstructionArgs
impl Clone for SetRewardAuthorityInstructionArgs
impl Clone for SetRewardAuthorityInstructionArgs
fn clone(&self) -> SetRewardAuthorityInstructionArgs
fn clone(&self) -> SetRewardAuthorityInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for SetRewardAuthorityInstructionArgs
impl Debug for SetRewardAuthorityInstructionArgs
impl Eq for SetRewardAuthorityInstructionArgs
impl StructuralPartialEq for SetRewardAuthorityInstructionArgs