Struct SetRewardEmissionsInstructionArgs
pub struct SetRewardEmissionsInstructionArgs {
pub reward_index: u8,
pub emissions_per_second_x64: u128,
}Fields
reward_index: u8emissions_per_second_x64: u128Trait Implementations
impl BorshDeserialize for SetRewardEmissionsInstructionArgs
impl BorshDeserialize for SetRewardEmissionsInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetRewardEmissionsInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetRewardEmissionsInstructionArgs
impl BorshSerialize for SetRewardEmissionsInstructionArgs
impl Clone for SetRewardEmissionsInstructionArgs
impl Clone for SetRewardEmissionsInstructionArgs
fn clone(&self) -> SetRewardEmissionsInstructionArgs
fn clone(&self) -> SetRewardEmissionsInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for SetRewardEmissionsInstructionArgs
impl Debug for SetRewardEmissionsInstructionArgs
impl Eq for SetRewardEmissionsInstructionArgs
impl StructuralPartialEq for SetRewardEmissionsInstructionArgs