Struct SetTokenBadgeAttributeInstructionArgs
pub struct SetTokenBadgeAttributeInstructionArgs {
pub attribute: TokenBadgeAttribute,
}Fields
attribute: TokenBadgeAttributeTrait Implementations
impl BorshDeserialize for SetTokenBadgeAttributeInstructionArgs
impl BorshDeserialize for SetTokenBadgeAttributeInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SetTokenBadgeAttributeInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SetTokenBadgeAttributeInstructionArgs
impl BorshSerialize for SetTokenBadgeAttributeInstructionArgs
impl Clone for SetTokenBadgeAttributeInstructionArgs
impl Clone for SetTokenBadgeAttributeInstructionArgs
fn clone(&self) -> SetTokenBadgeAttributeInstructionArgs
fn clone(&self) -> SetTokenBadgeAttributeInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for SetTokenBadgeAttributeInstructionArgs
impl PartialEq for SetTokenBadgeAttributeInstructionArgs
fn eq(&self, other: &SetTokenBadgeAttributeInstructionArgs) -> bool
fn eq(&self, other: &SetTokenBadgeAttributeInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetTokenBadgeAttributeInstructionArgs
impl StructuralPartialEq for SetTokenBadgeAttributeInstructionArgs