Struct SwapInstructionArgs
pub struct SwapInstructionArgs {
pub amount: u64,
pub other_amount_threshold: u64,
pub sqrt_price_limit: u128,
pub amount_specified_is_input: bool,
pub a_to_b: bool,
}Fields
amount: u64other_amount_threshold: u64sqrt_price_limit: u128amount_specified_is_input: boola_to_b: boolTrait Implementations
impl BorshDeserialize for SwapInstructionArgs
impl BorshDeserialize for SwapInstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SwapInstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SwapInstructionArgs
impl BorshSerialize for SwapInstructionArgs
impl Clone for SwapInstructionArgs
impl Clone for SwapInstructionArgs
fn clone(&self) -> SwapInstructionArgs
fn clone(&self) -> SwapInstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for SwapInstructionArgs
impl Debug for SwapInstructionArgs
impl PartialEq for SwapInstructionArgs
impl PartialEq for SwapInstructionArgs
impl Eq for SwapInstructionArgs
impl StructuralPartialEq for SwapInstructionArgs