Struct SwapV2InstructionArgs
pub struct SwapV2InstructionArgs {
pub amount: u64,
pub other_amount_threshold: u64,
pub sqrt_price_limit: u128,
pub amount_specified_is_input: bool,
pub a_to_b: bool,
pub remaining_accounts_info: Option<RemainingAccountsInfo>,
}Fields
amount: u64other_amount_threshold: u64sqrt_price_limit: u128amount_specified_is_input: boola_to_b: boolremaining_accounts_info: Option<RemainingAccountsInfo>Trait Implementations
impl BorshDeserialize for SwapV2InstructionArgs
impl BorshDeserialize for SwapV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<SwapV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for SwapV2InstructionArgs
impl BorshSerialize for SwapV2InstructionArgs
impl Clone for SwapV2InstructionArgs
impl Clone for SwapV2InstructionArgs
fn clone(&self) -> SwapV2InstructionArgs
fn clone(&self) -> SwapV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for SwapV2InstructionArgs
impl Debug for SwapV2InstructionArgs
impl PartialEq for SwapV2InstructionArgs
impl PartialEq for SwapV2InstructionArgs
impl Eq for SwapV2InstructionArgs
impl StructuralPartialEq for SwapV2InstructionArgs