Struct Tick
pub struct Tick {
pub initialized: bool,
pub liquidity_net: i128,
pub liquidity_gross: u128,
pub fee_growth_outside_a: u128,
pub fee_growth_outside_b: u128,
pub reward_growths_outside: [u128; 3],
}Fields
initialized: boolliquidity_net: i128liquidity_gross: u128fee_growth_outside_a: u128fee_growth_outside_b: u128reward_growths_outside: [u128; 3]Trait Implementations
impl BorshDeserialize for Tick
impl BorshDeserialize for Tick
fn deserialize_reader<__R>(reader: &mut __R) -> Result<Tick, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl From<DynamicTick> for Tick
impl From<DynamicTick> for Tick
fn from(val: DynamicTick) -> Tick
fn from(val: DynamicTick) -> Tick
Converts to this type from the input type.
impl From<Tick> for DynamicTick
impl From<Tick> for DynamicTick
fn from(val: Tick) -> DynamicTick
fn from(val: Tick) -> DynamicTick
Converts to this type from the input type.
impl From<Tick> for TickFacade
impl From<Tick> for TickFacade
fn from(val: Tick) -> TickFacade
fn from(val: Tick) -> TickFacade
Converts to this type from the input type.
impl Eq for Tick
impl StructuralPartialEq for Tick