Struct Traded
pub struct Traded {
pub whirlpool: Address,
pub a_to_b: bool,
pub pre_sqrt_price: u128,
pub post_sqrt_price: u128,
pub input_amount: u64,
pub output_amount: u64,
pub input_transfer_fee: u64,
pub output_transfer_fee: u64,
pub lp_fee: u64,
pub protocol_fee: u64,
}Fields
whirlpool: Addressa_to_b: boolpre_sqrt_price: u128post_sqrt_price: u128input_amount: u64output_amount: u64input_transfer_fee: u64output_transfer_fee: u64lp_fee: u64protocol_fee: u64Trait Implementations
impl BorshDeserialize for Traded
impl BorshDeserialize for Traded
fn deserialize_reader<__R>(reader: &mut __R) -> Result<Traded, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl Eq for Traded
impl StructuralPartialEq for Traded