Struct TwoHopSwapV2InstructionArgs
pub struct TwoHopSwapV2InstructionArgs {
pub amount: u64,
pub other_amount_threshold: u64,
pub amount_specified_is_input: bool,
pub a_to_b_one: bool,
pub a_to_b_two: bool,
pub sqrt_price_limit_one: u128,
pub sqrt_price_limit_two: u128,
pub remaining_accounts_info: Option<RemainingAccountsInfo>,
}Fields
amount: u64other_amount_threshold: u64amount_specified_is_input: boola_to_b_one: boola_to_b_two: boolsqrt_price_limit_one: u128sqrt_price_limit_two: u128remaining_accounts_info: Option<RemainingAccountsInfo>Trait Implementations
impl BorshDeserialize for TwoHopSwapV2InstructionArgs
impl BorshDeserialize for TwoHopSwapV2InstructionArgs
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<TwoHopSwapV2InstructionArgs, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for TwoHopSwapV2InstructionArgs
impl BorshSerialize for TwoHopSwapV2InstructionArgs
impl Clone for TwoHopSwapV2InstructionArgs
impl Clone for TwoHopSwapV2InstructionArgs
fn clone(&self) -> TwoHopSwapV2InstructionArgs
fn clone(&self) -> TwoHopSwapV2InstructionArgs
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for TwoHopSwapV2InstructionArgs
impl Debug for TwoHopSwapV2InstructionArgs
impl PartialEq for TwoHopSwapV2InstructionArgs
impl PartialEq for TwoHopSwapV2InstructionArgs
impl Eq for TwoHopSwapV2InstructionArgs
impl StructuralPartialEq for TwoHopSwapV2InstructionArgs