Struct WhirlpoolRewardInfo
pub struct WhirlpoolRewardInfo {
pub mint: Address,
pub vault: Address,
pub extension: [u8; 32],
pub emissions_per_second_x64: u128,
pub growth_global_x64: u128,
}Expand description
Stores the state relevant for tracking liquidity mining rewards at the Whirlpool level.
These values are used in conjunction with PositionRewardInfo, Tick.reward_growths_outside,
and Whirlpool.reward_last_updated_timestamp to determine how many rewards are earned by open
positions.
Fields
mint: AddressReward token mint.
vault: AddressReward vault token account.
extension: [u8; 32]reward_infos[0]: Authority account that has permission to initialize the reward and set emissions. reward_infos[1]: used for a struct that contains fields for extending the functionality of Whirlpool. reward_infos[2]: reserved for future use.
Historical notes: Originally, this was a field named “authority”, but it was found that there was no opportunity to set different authorities for the three rewards. Therefore, the use of this field was changed for Whirlpool’s future extensibility.
emissions_per_second_x64: u128Q64.64 number that indicates how many tokens per second are earned per unit of liquidity.
growth_global_x64: u128Q64.64 number that tracks the total tokens earned per unit of liquidity since the reward emissions were turned on.